@@ -1,8 +1,10 @@
 """
 Miscellaneous  functionality relating to metadata.
 """
+
 import datetime
 
+
 class MetadataItem:
     """
     Convenience class for working with a metadata element.
@@ -24,7 +26,7 @@ class MetadataItem:
     VALID_TYPES = {
         'link', 'string', 'boolean', 'decimal', 'integer', 'dateTime'
     }
-    DATE_CLASSES = {datetime.datetime, datetime.date, datetime.time,}
+    DATE_CLASSES = {datetime.datetime, datetime.date, datetime.time}
 
     # Reference:  https://numpy.org/doc/stable/user/basics.types.html
     NUMPY_INT_CLASS_NAMES = {
